@@ -43,7 +43,7 @@
 
 #define THUMB_BORDER   14
 #define ADD_LIST_DELAY 30
-#define ADD_LIST_CHUNK 400
+#define ADD_LIST_CHUNK 500
 #define SCROLL_DELAY   20
 #define DEF_THUMB_SIZE 128
 
@@ -1099,7 +1099,7 @@ gth_file_list_select_image_by_pos (GthFileList *file_list,
 
 	visibility = gth_file_view_image_is_visible (file_list->view, pos);
 	if (visibility != GTH_VISIBILITY_FULL) {
-		double offset;
+		double offset = 0.5;
 		switch (visibility) {
 		case GTH_VISIBILITY_NONE:
 			offset = 0.5; 
