@@ -30,6 +30,7 @@
 #include "gth-image-list.h"
 #include "file-data.h"
 #include "icons/pixbufs.h"
+#include "pixbuf-utils.h"
 
 
 struct _GthFileViewThumbsPrivate {
@@ -782,6 +783,7 @@ create_unknown_pixbuf (GthFileViewThumbs *gfv_thumbs)
 	char       *icon_name;
 	char       *icon_path;
 	GdkPixbuf  *pixbuf = NULL;
+	int         width, height;
 
 	icon_size = get_default_icon_size (GTK_WIDGET (gfv_thumbs->priv->ilist));
 
@@ -810,26 +812,16 @@ create_unknown_pixbuf (GthFileViewThumbs *gfv_thumbs)
 		g_free (icon_path);
 	}
 
-	if ((gdk_pixbuf_get_width (pixbuf) > icon_size)
-	    || (gdk_pixbuf_get_height (pixbuf) > icon_size)) {
-		int        new_w, new_h;
-		int        w, h;
-		double     factor;
-		GdkPixbuf *tmp;
-		
-		w = gdk_pixbuf_get_width (pixbuf);
-		h = gdk_pixbuf_get_height (pixbuf);
-
-		factor = MIN ((double) icon_size / w, (double) icon_size / h);
-		new_w  = MAX ((int) (factor * w), 1);
-		new_h  = MAX ((int) (factor * h), 1);
-
-		tmp = gdk_pixbuf_scale_simple (pixbuf,
-					       new_w,
-					       new_h,
-					       GDK_INTERP_BILINEAR);
+	width = gdk_pixbuf_get_width (pixbuf);
+	height = gdk_pixbuf_get_height (pixbuf);
+	if (scale_keepping_ratio (&width, &height, icon_size, icon_size)) {
+		GdkPixbuf *scaled;
+		scaled = gdk_pixbuf_scale_simple (pixbuf,
+						  width,
+						  height,
+						  GDK_INTERP_BILINEAR);
 		g_object_unref (pixbuf);
-		pixbuf = tmp;
+		pixbuf = scaled;
 	}
 
 	return pixbuf;
