@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 The Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -564,20 +564,20 @@ _gdk_pixbuf_save_as_jpeg (GdkPixbuf     *pixbuf,
 			  char         **values,
 			  GError       **error)
 {
-	FILE         *file;
 	struct jpeg_compress_struct cinfo;
 	struct error_handler_data jerr;
-	guchar       *buf = NULL;
-	guchar       *ptr;
-	guchar       *pixels = NULL;
-	int           quality     = 75; /* default; must be between 0 and 100 */
-	int           smoothing   = 0;
-	gboolean      optimize    = FALSE;
-	gboolean      progressive = FALSE;
-	int           i, j;
-	int           w, h = 0;
-	int           rowstride = 0;
-	int           bpp;
+	FILE              *file;
+	guchar            *buf = NULL;
+	guchar            *ptr;
+	guchar            *pixels = NULL;
+	volatile int       quality = 75; /* default; must be between 0 and 100 */
+	volatile int       smoothing = 0;
+	volatile gboolean  optimize = FALSE;
+	volatile gboolean  progressive = FALSE;
+	int                i, j;
+	int                w, h = 0;
+	int                rowstride = 0;
+	volatile int       bpp;
 
 	if (keys && *keys) {
 		char **kiter = keys;
@@ -1018,7 +1018,7 @@ rle_write (FILE   *fp,
 	int     repeat = 0;
 	int     direct = 0;
 	guchar *from   = buffer;
-	int     x;
+	guint   x;
 	
 	for (x = 1; x < width; ++x) {
 		if (memcmp (buffer, buffer + bytes, bytes)) {
@@ -1270,13 +1270,12 @@ _gdk_pixbuf_savev (GdkPixbuf    *pixbuf,
 						   error);
 	else
 #endif
-	if ((strcmp (type, "x-tga") == 0) ||  (strcmp (type, "tga") == 0))
+	if ((strcmp (type, "x-tga") == 0) || (strcmp (type, "tga") == 0))
 		result = _gdk_pixbuf_save_as_tga (pixbuf, 
 						  filename, 
 						  keys, values, 
 						  error);
 	else
-
 		result = gdk_pixbuf_savev (pixbuf, filename, type,
 					   keys, values,
 					   error);
@@ -1350,3 +1349,34 @@ _gdk_pixbuf_save (GdkPixbuf    *pixbuf,
 
 	return result;
 }
+
+
+gboolean
+scale_keepping_ratio (int *width,
+		      int *height,
+		      int  max_width,
+		      int  max_height)
+{
+	double   w = *width;
+	double   h = *height;
+	double   max_w = max_width;
+	double   max_h = max_height;
+	double   factor;
+	int      new_width, new_height;
+	gboolean modified;
+
+	if ((*width < max_width) && (*height < max_height)) 
+		return FALSE;
+
+	factor = MIN (max_w / w, max_h / h);
+	new_width  = MAX ((int) floor (w * factor + 0.50), 1);
+	new_height = MAX ((int) floor (h * factor + 0.50), 1);
+	
+	modified = (new_width != *width) || (new_height != *height);
+
+	*width = new_width;
+	*height = new_height;
+
+	return modified;
+}
+
