@@ -32,6 +32,7 @@ DEFINE_VERB(file_new_window_command_impl);
 DEFINE_VERB(file_close_window_command_impl);
 DEFINE_VERB(file_open_with_command_impl);
 DEFINE_VERB(file_print_command_impl);
+DEFINE_VERB(file_camera_import_command_impl);
 DEFINE_VERB(file_save_command_impl);
 DEFINE_VERB(file_revert_command_impl);
 DEFINE_VERB(file_exit_command_impl);
@@ -57,17 +58,21 @@ DEFINE_VERB(edit_current_delete_comment_command_impl);
 DEFINE_VERB(edit_current_edit_categories_command_impl);
 DEFINE_VERB(edit_add_to_catalog_command_impl);
 DEFINE_VERB(edit_remove_from_catalog_command_impl);
+DEFINE_VERB(edit_folder_view_command_impl);
+DEFINE_VERB(edit_folder_view_new_window_command_impl);
 DEFINE_VERB(edit_folder_open_nautilus_command_impl);
 DEFINE_VERB(edit_folder_rename_command_impl);
 DEFINE_VERB(edit_folder_delete_command_impl);
 DEFINE_VERB(edit_folder_copy_command_impl);
 DEFINE_VERB(edit_folder_move_command_impl);
+DEFINE_VERB(edit_folder_categories_command_impl);
 DEFINE_VERB(edit_current_folder_new_command_impl);
 DEFINE_VERB(edit_current_folder_open_nautilus_command_impl);
 DEFINE_VERB(edit_current_folder_rename_command_impl);
 DEFINE_VERB(edit_current_folder_delete_command_impl);
 DEFINE_VERB(edit_current_folder_copy_command_impl);
 DEFINE_VERB(edit_current_folder_move_command_impl);
+DEFINE_VERB(edit_current_folder_categories_command_impl);
 DEFINE_VERB(edit_catalog_rename_command_impl);
 DEFINE_VERB(edit_catalog_delete_command_impl);
 DEFINE_VERB(edit_catalog_move_command_impl);
@@ -80,8 +85,8 @@ DEFINE_VERB(edit_current_catalog_delete_command_impl);
 DEFINE_VERB(edit_current_catalog_move_command_impl);
 DEFINE_VERB(edit_current_catalog_edit_search_command_impl);
 DEFINE_VERB(edit_current_catalog_redo_search_command_impl);
-DEFINE_VERB(alter_image_rotate_command_impl);
-DEFINE_VERB(alter_image_rotate_cc_command_impl);
+DEFINE_VERB(alter_image_rotate_90_command_impl);
+DEFINE_VERB(alter_image_rotate_90_cc_command_impl);
 DEFINE_VERB(alter_image_flip_command_impl);
 DEFINE_VERB(alter_image_mirror_command_impl);
 DEFINE_VERB(alter_image_desaturate_command_impl);
@@ -95,6 +100,7 @@ DEFINE_VERB(alter_image_color_balance_command_impl);
 DEFINE_VERB(alter_image_scale_command_impl);
 DEFINE_VERB(alter_image_stretch_contrast_command_impl);
 DEFINE_VERB(alter_image_normalize_contrast_command_impl);
+DEFINE_VERB(alter_image_crop_command_impl);
 DEFINE_VERB(view_zoom_in_command_impl);
 DEFINE_VERB(view_zoom_out_command_impl);
 DEFINE_VERB(view_zoom_100_command_impl);
