@@ -830,6 +830,7 @@ file_respects_search_criteria (DialogData *data,
 	char        *place;
 	int          keywords_n;
 	time_t       time = 0;
+	const char  *home_dir;
 	const char  *name_only;
 
 	if (! file_is_image (filename, eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, TRUE)))
@@ -887,7 +888,11 @@ file_respects_search_criteria (DialogData *data,
 		 && (time > data->search_data->date + ONE_DAY))
 		match_date = TRUE;
 
-	name_only = file_name_from_path (filename);
+	home_dir = g_get_home_dir ();
+	if (path_in_path (home_dir, filename))
+		name_only = filename + strlen (home_dir);
+	else
+		name_only = filename;
 
 	result = (match_patterns (data->file_patterns, name_only)
 		  && match_patterns (data->comment_patterns, comment)
