@@ -976,12 +976,24 @@ load_session (void)
 
 
 int
-get_default_folder_pixbuf_size (GtkWidget *widget)
+get_folder_pixbuf_size_for_list (GtkWidget *widget)
 {
 	int icon_width, icon_height;
 
 	gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (widget),
-                                           ICON_GTK_SIZE,
+                                           GTK_ICON_SIZE_SMALL_TOOLBAR,
+                                           &icon_width, &icon_height);
+	return MAX (icon_width, icon_height);
+}
+
+
+int
+get_folder_pixbuf_size_for_menu (GtkWidget *widget)
+{
+	int icon_width, icon_height;
+
+	gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (widget),
+                                           GTK_ICON_SIZE_MENU,
                                            &icon_width, &icon_height);
 	return MAX (icon_width, icon_height);
 }
